This function executes the comparison of two data frames, generates the differences, and writes them to specified output files.

execute_data_diffs(.base_df, .compare_df, .subject_col, .print_output = TRUE)

Arguments

.base_df

A data frame that serves as the base for comparison.

.compare_df

A data frame to compare against the base data frame.

.subject_col

A string representing the column name to be used for subject-based differences. Set to NULL for data frames not containing an subject column.

.print_output

Logical. Should console output be printed?

Value

A list with elements diffs, standard_diffs, and variable_diffs (tibbles summarizing the differences).